@@ -1,46 +1,32 @@
-import builtins
-import unittest.mock
-from typing import cast, overload, Generator, Mapping, Iterable, Tuple, TypeVar
-from typing import Any
-from typing import Callable
-from typing import Dict
-from typing import List
-
-from typing import Optional
-from typing import Union
-
-
 import asyncio
+import builtins
 import functools
 import inspect
-import warnings
 import sys
+import unittest.mock
+import warnings
+from typing import Any
+from typing import Callable
+from typing import cast
+from typing import Dict
+from typing import Generator
+from typing import Iterable
+from typing import List
+from typing import Mapping
+from typing import Optional
+from typing import overload
+from typing import Tuple
+from typing import TypeVar
+from typing import Union
 
 import pytest
 
+from ._util import get_mock_module
+from ._util import parse_ini_boolean
+
 _T = TypeVar("_T")
 
 
-def _get_mock_module(config):
-    """
-    Import and return the actual "mock" module. By default this is
-    "unittest.mock", but the user can force to always use "mock" using
-    the mock_use_standalone_module ini option.
-    """
-    if not hasattr(_get_mock_module, "_module"):
-        use_standalone_module = parse_ini_boolean(
-            config.getini("mock_use_standalone_module")
-        )
-        if use_standalone_module:
-            import mock
-
-            _get_mock_module._module = mock
-        else:
-            _get_mock_module._module = unittest.mock
-
-    return _get_mock_module._module
-
-
 class PytestMockWarning(UserWarning):
     """Base class for all warnings emitted by pytest-mock."""
 
@@ -54,7 +40,7 @@ class MockerFixture:
     def __init__(self, config: Any) -> None:
         self._patches = []  # type: List[Any]
         self._mocks = []  # type: List[Any]
-        self.mock_module = mock_module = _get_mock_module(config)
+        self.mock_module = mock_module = get_mock_module(config)
         self.patch = self._Patcher(
             self._patches, self._mocks, mock_module
         )  # type: MockerFixture._Patcher
@@ -74,10 +60,17 @@ class MockerFixture:
         if hasattr(mock_module, "seal"):
             self.seal = mock_module.seal
 
-    def resetall(self) -> None:
-        """Call reset_mock() on all patchers started by this fixture."""
+    def resetall(
+        self, *, return_value: bool = False, side_effect: bool = False
+    ) -> None:
+        """
+        Call reset_mock() on all patchers started by this fixture.
+
+        :param bool return_value: Reset the return_value of mocks.
+        :param bool side_effect: Reset the side_effect of mocks.
+        """
         for m in self._mocks:
-            m.reset_mock()
+            m.reset_mock(return_value=return_value, side_effect=side_effect)
 
     def stopall(self) -> None:
         """
@@ -99,20 +92,14 @@ class MockerFixture:
         :return: Spy object.
         """
         method = getattr(obj, name)
-
-        autospec = inspect.ismethod(method) or inspect.isfunction(method)
-        # Can't use autospec classmethod or staticmethod objects
-        # see: https://bugs.python.org/issue23078
-        if inspect.isclass(obj):
-            # Bypass class descriptor:
-            # http://stackoverflow.com/questions/14187973/python3-check-if-method-is-static
-            try:
-                value = obj.__getattribute__(obj, name)  # type:ignore
-            except AttributeError:
-                pass
-            else:
-                if isinstance(value, (classmethod, staticmethod)):
-                    autospec = False
+        if inspect.isclass(obj) and isinstance(
+            inspect.getattr_static(obj, name), (classmethod, staticmethod)
+        ):
+            # Can't use autospec classmethod or staticmethod objects before 3.7
+            # see: https://bugs.python.org/issue23078
+            autospec = False
+        else:
+            autospec = inspect.ismethod(method) or inspect.isfunction(method)
 
         def wrapper(*args, **kwargs):
             spy_obj.spy_return = None
@@ -287,7 +274,7 @@ class MockerFixture:
 
         def dict(
             self,
-            in_dict: Mapping[Any, Any],
+            in_dict: Union[Mapping[Any, Any], str],
             values: Union[Mapping[Any, Any], Iterable[Tuple[Any, Any]]] = (),
             clear: bool = False,
             **kwargs: Any
@@ -518,7 +505,7 @@ def wrap_assert_methods(config: Any) -> None:
     if _mock_module_originals:
         return
 
-    mock_module = _get_mock_module(config)
+    mock_module = get_mock_module(config)
 
     wrappers = {
         "assert_called": wrap_assert_called,
@@ -594,16 +581,6 @@ def pytest_addoption(parser: Any) -> None:
     )
 
 
-def parse_ini_boolean(value: Union[bool, str]) -> bool:
-    if isinstance(value, bool):
-        return value
-    if value.lower() == "true":
-        return True
-    if value.lower() == "false":
-        return False
-    raise ValueError("unknown string for bool: %r" % value)
-
-
 def pytest_configure(config: Any) -> None:
     tb = config.getoption("--tb", default="auto")
     if (
