@@ -3,11 +3,17 @@ import platform
 import re
 import sys
 from contextlib import contextmanager
-from typing import Callable, Any, Tuple, Generator, Type
+from typing import Any
+from typing import Callable
+from typing import Generator
+from typing import Tuple
+from typing import Type
 from unittest.mock import MagicMock
 
 import pytest
-from pytest_mock import MockerFixture, PytestMockWarning
+
+from pytest_mock import MockerFixture
+from pytest_mock import PytestMockWarning
 
 pytest_plugins = "pytester"
 
@@ -162,20 +168,20 @@ def test_mock_patch_dict_resetall(mocker: MockerFixture) -> None:
     ],
 )
 def test_mocker_aliases(name: str, pytestconfig: Any) -> None:
-    from pytest_mock.plugin import _get_mock_module
+    from pytest_mock._util import get_mock_module
 
-    mock_module = _get_mock_module(pytestconfig)
+    mock_module = get_mock_module(pytestconfig)
 
     mocker = MockerFixture(pytestconfig)
     assert getattr(mocker, name) is getattr(mock_module, name)
 
 
 def test_mocker_resetall(mocker: MockerFixture) -> None:
-    listdir = mocker.patch("os.listdir")
-    open = mocker.patch("os.open")
+    listdir = mocker.patch("os.listdir", return_value="foo")
+    open = mocker.patch("os.open", side_effect=["bar", "baz"])
 
-    listdir("/tmp")
-    open("/tmp/foo.txt")
+    assert listdir("/tmp") == "foo"
+    assert open("/tmp/foo.txt") == "bar"
     listdir.assert_called_once_with("/tmp")
     open.assert_called_once_with("/tmp/foo.txt")
 
@@ -183,6 +189,13 @@ def test_mocker_resetall(mocker: MockerFixture) -> None:
 
     assert not listdir.called
     assert not open.called
+    assert listdir.return_value == "foo"
+    assert list(open.side_effect) == ["baz"]
+
+    mocker.resetall(return_value=True, side_effect=True)
+
+    assert isinstance(listdir.return_value, mocker.Mock)
+    assert open.side_effect is None
 
 
 class TestMockerStub:
@@ -249,7 +262,8 @@ def test_instance_method_spy(mocker: MockerFixture) -> None:
     ),
 )
 def test_instance_method_spy_exception(
-    exc_cls: Type[BaseException], mocker: MockerFixture,
+    exc_cls: Type[BaseException],
+    mocker: MockerFixture,
 ) -> None:
     class Foo:
         def bar(self, arg):
@@ -268,6 +282,19 @@ def test_instance_method_spy_exception(
         assert str(spy.spy_exception) == "Error with {}".format(v)
 
 
+def test_instance_method_spy_autospec_true(mocker: MockerFixture) -> None:
+    class Foo:
+        def bar(self, arg):
+            return arg * 2
+
+    foo = Foo()
+    spy = mocker.spy(foo, "bar")
+    with pytest.raises(
+        AttributeError, match="'function' object has no attribute 'fake_assert_method'"
+    ):
+        spy.fake_assert_method(arg=5)
+
+
 def test_spy_reset(mocker: MockerFixture) -> None:
     class Foo(object):
         def bar(self, x):
@@ -342,6 +369,17 @@ def test_class_method_spy(mocker: MockerFixture) -> None:
     assert spy.spy_return == 20
 
 
+@skip_pypy
+def test_class_method_spy_autospec_false(mocker: MockerFixture) -> None:
+    class Foo:
+        @classmethod
+        def bar(cls, arg):
+            return arg * 2
+
+    spy = mocker.spy(Foo, "bar")
+    spy.fake_assert_method()
+
+
 @skip_pypy
 def test_class_method_subclass_spy(mocker: MockerFixture) -> None:
     class Base:
@@ -603,12 +641,12 @@ def test_monkeypatch_ini(testdir: Any, mocker: MockerFixture) -> None:
 
 
 def test_parse_ini_boolean() -> None:
-    import pytest_mock
+    from pytest_mock._util import parse_ini_boolean
 
-    assert pytest_mock.parse_ini_boolean("True") is True
-    assert pytest_mock.parse_ini_boolean("false") is False
+    assert parse_ini_boolean("True") is True
+    assert parse_ini_boolean("false") is False
     with pytest.raises(ValueError):
-        pytest_mock.parse_ini_boolean("foo")
+        parse_ini_boolean("foo")
 
 
 def test_patched_method_parameter_name(mocker: MockerFixture) -> None:
@@ -627,8 +665,7 @@ def test_patched_method_parameter_name(mocker: MockerFixture) -> None:
 
 
 def test_monkeypatch_native(testdir: Any) -> None:
-    """Automatically disable monkeypatching when --tb=native.
-    """
+    """Automatically disable monkeypatching when --tb=native."""
     testdir.makepyfile(
         """
         def test_foo(mocker):
@@ -652,8 +689,7 @@ def test_monkeypatch_native(testdir: Any) -> None:
 
 
 def test_monkeypatch_no_terminal(testdir: Any) -> None:
-    """Don't crash without 'terminal' plugin.
-    """
+    """Don't crash without 'terminal' plugin."""
     testdir.makepyfile(
         """
         def test_foo(mocker):
@@ -668,8 +704,7 @@ def test_monkeypatch_no_terminal(testdir: Any) -> None:
 
 
 def test_standalone_mock(testdir: Any) -> None:
-    """Check that the "mock_use_standalone" is being used.
-    """
+    """Check that the "mock_use_standalone" is being used."""
     testdir.makepyfile(
         """
         def test_foo(mocker):
@@ -689,8 +724,7 @@ def test_standalone_mock(testdir: Any) -> None:
 
 @pytest.mark.usefixtures("needs_assert_rewrite")
 def test_detailed_introspection(testdir: Any) -> None:
-    """Check that the "mock_use_standalone" is being used.
-    """
+    """Check that the "mock_use_standalone" is being used."""
     testdir.makepyfile(
         """
         def test(mocker):
@@ -731,8 +765,7 @@ def test_detailed_introspection(testdir: Any) -> None:
 )
 @pytest.mark.usefixtures("needs_assert_rewrite")
 def test_detailed_introspection_async(testdir: Any) -> None:
-    """Check that the "mock_use_standalone" is being used.
-    """
+    """Check that the "mock_use_standalone" is being used."""
     testdir.makepyfile(
         """
         import pytest
